@@ -20,6 +20,7 @@ from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.utils.files import FilesError
 from calculate.desktop.desktop import DesktopError
 from calculate.client.client import ClientError
+from calculate.lib.utils.samba import SambaError
 from calculate.lib.cl_template import TemplatesError
 
 _ = lambda x: x
@@ -32,7 +33,8 @@ class ClPasswdAction(Action):
     Изменить пароль доменного пользователя
     """
     # ошибки, которые отображаются без подробностей
-    native_error = (FilesError, DesktopError, TemplatesError, ClientError)
+    native_error = (FilesError, ClientError, DesktopError, TemplatesError,
+                    SambaError)
 
     successMessage = (__("{cl_client_login}'s password changed\n"
                          "This modification will be applied when "
