@@ -845,6 +845,20 @@ class VariableClCifsutilsVer(ReadonlyVariable):
             return data[0]['PV']
         return ""
 
+class VariableClClientIgnoreErrorsSet(Variable):
+    """
+    Параметр, для отключения отмонтирования пользовательских ресурсов,
+    при ошбиках, возникших во вермя cl-client-sync-login
+    """
+    type = "bool"
+    value = "on"
+    metavalue = "ON/OFF"
+
+    opt = ["--unmount-on-error"]
+
+    def init(self):
+        self.label = _("Unmount user resources on error")
+        self.help = _("unmount user resources on error")
 
 class VariableClSyncMovedSet(Variable):
     """
